@@ -1,9 +1,11 @@
-predict.lognet=function(object,newx,s=NULL,type=c("link","response","coefficients","class","nonzero"),exact=FALSE,offset,...){
+#' @method predict lognet
+#' @export
+predict.lognet=function(object,newx,s=NULL,type=c("link","response","coefficients","class","nonzero"),exact=FALSE,newoffset,...){
   type=match.arg(type)
     ### remember that although the fortran lognet makes predictions
   ### for the first class, we make predictions for the second class
   ### to avoid confusion with 0/1 responses.
-  ### glmnet flipped the signs of the coefficients 
+  ### glmnet flipped the signs of the coefficients
 nfit=NextMethod("predict")
   switch(type,
          response={
@@ -18,5 +20,5 @@ nfit=NextMethod("predict")
          },
          nfit
          )
-}  
-    
+}
+
